Learn R Programming

discretes (version 0.1.0)

representative: Get a representative discrete value in a numeric series

Description

Get a representative discrete value in a numeric series

Usage

representative(x)

Value

A single numeric: a representative discrete value from the numeric series, with the proper mode.

Arguments

x

Numeric series (numeric vector or object of class "discretes").

Examples

Run this code
representative(integers())
representative(natural1() + 7)

Run the code above in your browser using DataLab