powered by
Get a representative discrete value in a numeric series
representative(x)
A single numeric: a representative discrete value from the numeric series, with the proper mode.
Numeric series (numeric vector or object of class "discretes").
numeric
"discretes"
representative(integers()) representative(natural1() + 7)
Run the code above in your browser using DataLab